Skip to contents

Returns the smoothed estimate of the latent efficient value for the in-sample periods, i.e. the model's revision-adjusted signal.

Usage

# S3 method for class 'kk_model'
fitted(object, ...)

Arguments

object

An object of class kk_model.

...

Ignored.

Value

A tibble with columns time, estimate, lower and upper.

Examples

df <- get_nth_release(
  tsbox::ts_span(
    tsbox::ts_pc(dplyr::filter(reviser::gdp, id == "US")),
    start = "1980-01-01"
  ),
  n = 0:1
)
df <- na.omit(dplyr::select(df, -c("id", "pub_date")))
fit <- kk_nowcast(df, e = 1, model = "KK", method = "MLE")
head(fitted(fit))
#> # A tibble: 6 × 4
#>   time       estimate  lower  upper
#>   <date>        <dbl>  <dbl>  <dbl>
#> 1 1980-07-01   -0.154 -0.157 -0.152
#> 2 1980-10-01    1.78   1.78   1.78 
#> 3 1981-01-01    1.94   1.94   1.95 
#> 4 1981-04-01   -0.699 -0.702 -0.697
#> 5 1981-07-01    1.19   1.19   1.19 
#> 6 1981-10-01   -1.18  -1.18  -1.18