Skip to contents

Returns the effective number of observations behind the reported information criteria. Under the default ic_n = "Tp" this is the number of time periods times the number of vintages modeled.

Usage

# S3 method for class 'jvn_model'
nobs(object, ...)

Arguments

object

An object of class jvn_model.

...

Ignored.

Value

A single integer.

Examples

# \donttest{
gdp_growth <- dplyr::filter(
  tsbox::ts_pc(reviser::gdp),
  id == "EA",
  time >= min(pub_date),
  time <= as.Date("2020-01-01")
)
gdp_growth <- tidyr::drop_na(gdp_growth)
df <- get_nth_release(gdp_growth, n = 0:3)

fit <- jvn_nowcast(df = df, e = 4, ar_order = 2, include_noise = FALSE)
nobs(fit)
#> [1] 70
# }