Skip to contents

Returns the effective number of observations behind the reported information criteria. Under the default ic_n = "Tp" this is the number of time periods times the number of releases modeled.

Usage

# S3 method for class 'kk_model'
nobs(object, ...)

Arguments

object

An object of class kk_model.

...

Ignored.

Value

A single integer.

Examples

df <- get_nth_release(
  tsbox::ts_span(
    tsbox::ts_pc(dplyr::filter(reviser::gdp, id == "US")),
    start = "1980-01-01"
  ),
  n = 0:1
)
df <- na.omit(dplyr::select(df, -c("id", "pub_date")))
fit <- kk_nowcast(df, e = 1, model = "KK", method = "MLE")
nobs(fit)
#> [1] 352