Returns the out-of-sample estimates of the model's latent signal produced
by the forecast horizon h supplied to kk_nowcast() or jvn_nowcast().
The horizon is fixed at estimation time, so refit with a different h to
change it.
Usage
# S3 method for class 'revision_model'
predict(object, ...)Arguments
- object
A fitted model object inheriting from revision_model, such as a
kk_modelor ajvn_model.- ...
Ignored.
Value
A tibble with columns time, estimate, lower and upper.
Has zero rows when the model was fitted with h = 0.
See also
Other revision nowcasting:
coef.revision_model(),
fitted.revision_model(),
jvn_nowcast(),
kk_nowcast(),
logLik.revision_model(),
nobs.revision_model(),
plot.revision_model(),
print.revision_model(),
residuals.revision_model(),
revision_model,
states(),
summary.revision_model(),
vcov.revision_model()
Examples
df <- get_nth_release(
tsbox::ts_span(
tsbox::ts_pc(dplyr::filter(reviser::gdp, id == "US")),
start = "1980-01-01"
),
n = 0:1
)
df <- na.omit(dplyr::select(df, -c("id", "pub_date")))
fit <- kk_nowcast(df, e = 1, h = 2, model = "KK", method = "MLE")
predict(fit)
#> # A tibble: 2 × 4
#> time estimate lower upper
#> <date> <dbl> <dbl> <dbl>
#> 1 2024-10-01 0.144 -2.33 2.62
#> 2 2025-01-01 0.0286 -2.50 2.55