Skip to contents

reviser is an R package designed for working with time-series vintages data. The package provides tools to clean, visualize, and analyze time-series revisions. To learn more about reviser, start with the vignettes: browseVignettes(package = "reviser") The package will be actively developed and maintained.

Useful links:

Author

Maintainer: Marc Burri marc.burri91@gmail.com (ORCID) [copyright holder]

Authors: