Skip to contents

Provides a custom header for objects of class tbl_release when printed.

Usage

# S3 method for class 'tbl_release'
tbl_sum(x, ...)

Arguments

x

An object of class tbl_release.

...

Additional arguments (unused).

Value

A named character vector where names are labels and values are the corresponding information.

Examples

df <- dplyr::filter(reviser::gdp, id == "US")
release_data <- get_nth_release(df, n = 0:3)
pillar::tbl_sum(release_data)
#> Vintages data (release format)                         Format 
#>                             ""                         "long" 
#>                   Time periods                       Releases 
#>                          "179"                            "4" 
#>                            IDs 
#>                            "1"