Returns the effective number of observations behind the reported
information criteria. Under the default ic_n = "Tp" this is the number
of time periods times the number of releases modeled.
Usage
# S3 method for class 'kk_model'
nobs(object, ...)See also
Other revision nowcasting:
coef.jvn_model(),
coef.kk_model(),
fitted.jvn_model(),
fitted.kk_model(),
jvn_nowcast(),
kk_nowcast(),
logLik.jvn_model(),
logLik.kk_model(),
nobs.jvn_model(),
plot.jvn_model(),
plot.kk_model(),
predict.jvn_model(),
predict.kk_model(),
print.jvn_model(),
print.kk_model(),
residuals.jvn_model(),
residuals.kk_model(),
states(),
summary.jvn_model(),
summary.kk_model(),
vcov.jvn_model(),
vcov.kk_model()
Examples
df <- get_nth_release(
tsbox::ts_span(
tsbox::ts_pc(dplyr::filter(reviser::gdp, id == "US")),
start = "1980-01-01"
),
n = 0:1
)
df <- na.omit(dplyr::select(df, -c("id", "pub_date")))
fit <- kk_nowcast(df, e = 1, model = "KK", method = "MLE")
nobs(fit)
#> [1] 352