Provides a custom header for objects of class tbl_pubdate when printed.
This method is called automatically by pillar when printing tibbles.
Value
A named character vector where names are labels and values are the corresponding information. The vector is used by pillar to format the tibble header.
Examples
df <- dplyr::filter(reviser::gdp, id == "US")
wide_data <- vintages_wide(df)
pillar::tbl_sum(wide_data$US)
#> Vintages data (publication date format) Time periods
#> "" "179"
#> Vintages
#> "89"